Skip to contents

A shared parent S4 class for elastic-based scatterers. The ELA-class collects the slots common to solid elastic targets such as calibration spheres (CAL) and elastic-shelled targets (ESS), without implying a particular internal structure such as a shell or homogeneous elastic solid. See Scatterer for a more detailed description of the shared object organization.

Value

An object of the ELA S4 class.

See also

Examples

methods::getClass("ELA")
#> Class "ELA" [package "acousticTS"]
#> 
#> Slots:
#>                                                                           
#> Name:             model             body shape_parameters         metadata
#> Class:             list             list             list             list
#>                        
#> Name:  model_parameters
#> Class:             list
#> 
#> Extends: "Scatterer"
#> 
#> Known Subclasses: "ESS", "CAL"