A S4 class that provides slots to contain relevant metadata for solid sphere
objects belonging to the CAL-class scatterers. This object is created using
parameters specific to the outer shell. The default behavior of this object
is to only reference these outer elastic shell properties with few
exceptions that are model-dependent. CAL inherits from the broader
elastic-based ELA class rather than from ESS, because
calibration targets are solid elastic bodies rather than elastic shells. See
Scatterer for a more detailed description on how this S4 object is
organized.