Convert between logarithmic (dB) and linear domains for backscatter values.
Source:R/acoustics.R
linear.RdThe linear function converts a value from the logarithmic (dB) domain to
the linear domain, while the db function converts a value from the linear
domain to the logarithmic (dB) domain. These are commonly used for target
strength (TS) and backscattering coefficient (\(\sigma_{bs}\)) conversions.
The conversions are defined as: $$\text{linear}(x) = c^{x / c}$$ $$\text{db}(x) = c \log_c(x)$$ where \(c\) is the coefficient (default 10).