Calculate the acoustic wavenumber (\(k\)) for a given frequency and sound speed.
Source:R/acoustics.R
wavenumber.RdCalculates the acoustic wavenumber (\(k\)) for a given frequency and sound speed in water. The wavenumber is defined as: $$k = \frac{2\pi f}{c}$$ where \(f\) is the frequency (Hz) and \(c\) is the sound speed (\(ms^{-1}\)). The wavenumber describes the spatial frequency of a sound wave and is fundamental in acoustic calculations.